Method: Hash#deep_stringify_keys

Defined in:
lib/simple_ext/hash/keys.rb

#deep_stringify_keysObject

Returns a new hash with all keys converted to strings. This includes the keys from the root hash and from all nested hashes and arrays.

hash = { person: { name: 'Rob', age: '28' } }

hash.deep_stringify_keys
# => {"person"=>{"name"=>"Rob", "age"=>"28"}}


84
85
86
# File 'lib/simple_ext/hash/keys.rb', line 84

def deep_stringify_keys
  deep_transform_keys(&:to_s)
end